@@ -27,8 +27,10 @@ def send_log_email():
     email_configuration = EmailConfiguration.objects.values(
         'SUBJECT',
         'HTML_File',
-        'LOG_PATH')
-
+        'LOG_PATH').first()
+    # SUBJECT = email_configuration.SUBJECT
+    # HTML_File = email_configuration.HTML_File
+    # LOG_PATH = email_configuration.LOG_PATH
     send_notifications(email, sender, email_configuration)
 
 
