@@ -8,7 +8,7 @@ from openlxp_notifications.management.utils.notification import \
 
 
 class ReceiverEmailConfiguration(TimeStampedModel):
-    """Model for Email Configuration """
+    """Model for Receiver Email Configuration """
 
     email_address = models.EmailField(
         max_length=254,
@@ -29,7 +29,7 @@ class ReceiverEmailConfiguration(TimeStampedModel):
 
 
 class SenderEmailConfiguration(TimeStampedModel):
-    """Model for Email Configuration """
+    """Model for Sender Email Configuration """
 
     sender_email_address = models.EmailField(
         max_length=254,
@@ -40,3 +40,24 @@ class SenderEmailConfiguration(TimeStampedModel):
             raise ValidationError('There is can be only one '
                                   'SenderEmailConfiguration instance')
         return super(SenderEmailConfiguration, self).save(*args, **kwargs)
+
+
+class EmailConfiguration(TimeStampedModel):
+    """Model for Email Configuration """
+
+    SUBJECT = models.CharField(max_length=200, null=True)
+
+    HTML_File = models.CharField(max_length=200, null=True)
+
+    LOG_PATH = models.CharField(max_length=200, null=True)
+
+    def get_absolute_url(self):
+        """ URL for displaying individual model records."""
+        return reverse('Configuration-detail', args=[str(self.id)])
+
+    def __str__(self):
+        """String for representing the Model object."""
+        return f'{self.id}'
+
+    def save(self, *args, **kwargs):
+        return super(EmailConfiguration, self).save(*args, **kwargs)
